***Replication Code for Mechanisms of Morality: Sources of Support for Humanitarian Intervention
*Sarah Kreps and Sarah Maxey
*March 2017
*This file replications the results from the Appendix. File 1 replicates the 
*results from the manuscript. Note, the mediation analysis uses simulations to 
*estimate the average causal mediation effect and percentage of the total effect 
*mediated through each mechanism. Estimates will vary slightly across iterations. 


version 12.1

*Set command directory to location where replication files are saved

*Appendix C. Experiment One
*C2. Sample Demographics
	*Load Data
	use "ExperimentOne.dta", clear
	
	tab1 democrat independent republican educ3 gender income3


*C3. Support by Treatment Condition
*Graph created in Excel based on output from:
prtest supportbi, by(treatmentid)

*C4. Comparison of Binary and Categorical Measures of Support
*Descriptive Comparison of Binary and Categorical Support by Treatment Scenario
*Binary Support
	*Foreign Policy Restraint
	tab supportbi if treatmentid==0
	*Humanitarian Intervention
	tab supportbi if treatmentid==1
	*Values in the "Effect of Humanitarian Intervention" column are calculated
	*by substracting the "Humanitarian Intervention" column from the
	*"Foreign Policy Restraint" column. 
*Categorical Support
	*Foreign Policy Restraint
	tab support if treatmentid==0
	*Humanitarian Intervention
	tab support if treatmentid==1
	*Values in the "Effect of Humanitarian Intervention" column are calculated
	*by substracting the "Humanitarian Intervention" column from the 
	*"Foreign Policy Restraint" column. 

*Binary and Categorical Comparison of Means by Treatment Scenario
	*Binary Support
	prtest supportbi, by(treatmentid)
	*Catgorical Support
	ttest support, by(treatmentid)

*C5. Mediation Analysis
*Results of Mediation Analysis without Controls
	*Moral Obligation
	medeff(logit moralbi treatmentid) (logit supportbi treatmentid moralbi), /// 
		treat(treatmentid) mediate(moralbi)
	*Burden-Sharing
	medeff(logit helpbi treatmentid) (logit supportbi treatmentid helpbi), /// 
		treat(treatmentid) mediate(helpbi)
	*High Casualties
	medeff(logit casualtiesbi treatmentid) (logit supportbi treatmentid casualtiesbi), /// 
		treat(treatmentid) mediate(casualtiesbi)
	*Financial Costs
	medeff(logit costsbi treatmentid) (logit supportbi treatmentid costsbi), /// 
		treat(treatmentid) mediate(costsbi)
	*Terrorism
	medeff(logit instabilitybi treatmentid) (logit supportbi treatmentid instabilitybi), /// 
		treat(treatmentid) mediate(instabilitybi)
	*Spillover
	medeff(logit spilloverbi treatmentid) (logit supportbi treatmentid spilloverbi), /// 
		treat(treatmentid) mediate(spilloverbi)
	*Economic Loss
	medeff(logit economicbi treatmentid) (logit supportbi treatmentid economicbi), /// 
		treat(treatmentid) mediate(economicbi)
	*Reputation
	medeff(logit resolvebi treatmentid) (logit supportbi treatmentid resolvebi), /// 
		treat(treatmentid) mediate(resolvebi)

*Mediation Analysis with Pretreatment Control Variables
local pretreatment1 donated volunteered awareness hawk gender news education pid
	*Moral Obligation
	medeff(logit moralbi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid moralbi `pretreatment1'), /// 
		treat(treatmentid) mediate(moralbi)
	*Burden-Sharing
	medeff(logit helpbi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid helpbi `pretreatment1'), /// 
		treat(treatmentid) mediate(helpbi)
	*High Casualties
	medeff(logit casualtiesbi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid casualtiesbi `pretreatment1'), /// 
		treat(treatmentid) mediate(casualtiesbi)
	*Financial Costs
	medeff(logit costsbi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid costsbi `pretreatment1'), /// 
		treat(treatmentid) mediate(costsbi)
	*Terrorism
	medeff(logit instabilitybi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid instabilitybi `pretreatment1'), /// 
		treat(treatmentid) mediate(instabilitybi)
	*Spillover
	medeff(logit spilloverbi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid spilloverbi `pretreatment1'), /// 
		treat(treatmentid) mediate(spilloverbi)
	*Economic Loss
	medeff(logit economicbi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid economicbi `pretreatment1'), /// 
		treat(treatmentid) mediate(economicbi)
	*Reputation
	medeff(logit resolvebi treatmentid `pretreatment1') /// 
		(logit supportbi treatmentid resolvebi `pretreatment1'), /// 
		treat(treatmentid) mediate(resolvebi)

*C6. Sensitivity Analysis
	*Model 1 (No Controls)
	medsens (logit moralbi treatmentid)(regress support treatmentid moralbi), /// 
		treat(treatmentid) mediate(moralbi)
	
	*Model 2 (Pretreatment Controls)
	medsens (logit moralbi treatmentid `pretreatment1') /// 
		(regress support treatmentid moralbi `pretreatment1'), /// 
		treat(treatmentid) mediate(moralbi)

macro drop pretreatment1
********************************************************************************
********************************************************************************
*Appendix D. Strategic Rationale Follow-Up Experiment
*Load Data
use "ExperimentFollowUps.dta", clear
*D1. Results
	*1. There is not a statistically significant difference between support for 
	*the original and revised FPR scenarios
	prtest supportbi if fpr1==1|fprnew==1, by(fprnew)
	
	*2. Support for HI remains significantly higher than either FPR alternative
	prtest supportbi if hi1==1|fpr1==1, by(fpr1)
	prtest supportbi if hi1==1|fprnew==1, by(fprnew)
	
	*3. No significant increase in perception that U.S. interests are at stake
	prtest interestbi if fpr1==1|fprnew==1, by(fprnew)
	
	*4. Sense of moral obligation higher in HI scenario compared to either FPR scenario
	prtest moralbi if hi1==1|fpr1==1, by(fpr1)
	prtest moralbi if hi1==1|fprnew==1, by(fprnew)
	
*D2. Support and Mechanisms in Alternative FPR Scenario
*Graph constructed in excel using point estimates and confidence intervals from 
*each of the following:
	*Support
	prtest supportbi if hi1==1|fpr1==1, by(fpr1)
	prtest supportbi if hi1==1|fprnew==1, by(fprnew)
	
	*Security Interest
	prtest interestbi if hi1==1|fpr1==1, by(fpr1)
	prtest interestbi if hi1==1|fprnew==1, by(fprnew)
	
	*Moral Obligation
	prtest moralbi if hi1==1|fpr1==1, by(fpr1)
	prtest moralbi if hi1==1|fprnew==1, by(fprnew)

*D4. Sample Demographics
	tab1 democrat independent republican educ3 gender if strategicrationale==1


********************************************************************************
********************************************************************************
*Appendix E. Experiment Two
*Load Data
use "ExperimentTwo.dta", clear

*E3. Sample Demographics
	tab1 pid3 educ3 gender income3
	
*E4. Probit Analysis of Humanitarian Intervention, Demographic Characteristics, and Support for War
probit supportbi hitreatment pid3 gender altruismmost altruismmost##hitreatment /// 
	hawkbi age education news moralbi boots

*E5. Comparison of Binary and Categorical Measures of Support
*Descriptive Comparison of Binary and Categorical Support by Treatment Scenario
*Binary Support
	*Foreign Policy Restraint
	tab supportbi if hitreatment==0
	*Humanitarian Intervention
	tab supportbi if hitreatment==1
	*Values in the "Effect of Humanitarian Intervention" column are calculated by 
	*substracting the "Humanitarian Intervention" column from the "Foreign Policy Restraint" column. 
*Categorical Support
	*Foreign Policy Restraint
	tab support if hitreatment==0
	*Humanitarian Intervention
	tab support if hitreatment==1
	*Values in the "Effect of Humanitarian Intervention" column are calculated by 
	*substracting the "Humanitarian Intervention" column from the "Foreign Policy Restraint" column. 

*Binary and Categorical Comparison of Means by Treatment Scenario
	*Binary Support
	prtest supportbi, by(hitreatment)
	*Catgorical Support
	ttest support, by(hitreatment)

*E6. Moderation Analysis
*Multilateral Help
	*Model
	logit supportbi hitreatment help2 hitreatment##help2
	*Marginal Effects Plot
	label define helptwo 0 "Low" 1 "High"
	label values help2 helptwo
	logit supportbi i.hitreatment i.help2
	margins, at(hitreatment=(0 1) help2=(0 1))
	marginsplot, title(Humanitarian Intervention by Help) /// 
		xtitle(Intervention Type) ytitle(Predicted Probability of Support) /// 
		legend(label(1 "Low") label(2 "High") /// 
		subtitle("Multilateral Help")rows(1)) xlabel(0 "FPR" 1 "HI") name(me1)
	
*Reputational Costs
	*Model
	logit supportbi hitreatment resolve2 hitreatment##resolve2
	*Marginal Effects Plot
	label define resolvetwo 0 "Low" 1 "High"
	label values resolve2 resolvetwo
	logit supportbi i.hitreatment i.resolve2
	margins, at(hitreatment=(0 1) resolve2=(0 1))
	marginsplot, title(Humanitarian Intervention by Reputational Costs) /// 
		xtitle(Intervention Type) ytitle(Predicted Probability of Support) /// 
		legend(label(1 "Low") label(2 "High")subtitle("Reputational Costs") /// 
		rows(1)) xlabel(0 "FPR" 1 "HI") name(me2)
	
*Combine graphs
graph combine me1 me2, ycommon altshrink
	
*E7. Mediation Analysis
*Results of Mediation Analysis without Controls
*Moral Obligation
	*Treatment Effect
	prtest moralbi, by(hitreatment)
	*ACME and % of Total Effect Mediated
	medeff(logit moralbi hitreatment) (logit supportbi hitreatment moralbi), /// 
		treat(hitreatment) mediate(moralbi)
*Boots on the ground
	*Treatment Effect
	prtest boots2, by(hitreatment)
	*ACME and % of Total Effect Mediated
	medeff(logit boots2 hitreatment) (logit supportbi hitreatment boots2), /// 
		treat(hitreatment) mediate(boots2)
*Own security
	*Treatment Effect
	prtest security, by(hitreatment)
	*ACME and % of Total Effect Mediated
	medeff(logit security hitreatment) (logit supportbi hitreatment security), /// 
		treat(hitreatment) mediate(security)
*Allies' security
	*Treatment Effect
	prtest othersecurity, by(hitreatment)
	*ACME and % of Total Effect Mediated
	medeff(logit othersecurity hitreatment) /// 
		(logit supportbi hitreatment othersecurity), /// 
		treat(hitreatment) mediate(othersecurity)

*Results of Mediation Analysis Controlling for Pretreatment Covariates
***Mediation analysis with pretreatment covariates as controls
local pretreatment2 altruism hawk gender news education pid
	*Moral Obligation
	medeff(logit moralbi hitreatment `pretreatment2') /// 
		(logit supportbi hitreatment moralbi `pretreatment2'), /// 
		treat(hitreatment) mediate(moralbi)
	*Boots on the ground
	medeff(logit boots2 hitreatment `pretreatment2') /// 
		(logit supportbi hitreatment boots2 `pretreatment2'), /// 
		treat(hitreatment) mediate(boots2)
	*Own security
	medeff(logit security hitreatment `pretreatment2') /// 
		(logit supportbi hitreatment security `pretreatment2'), /// 
		treat(hitreatment) mediate(security)
	*Allies' security
	medeff(logit othersecurity hitreatment `pretreatment2') /// 
		(logit supportbi hitreatment othersecurity `pretreatment2'), /// 
		treat(hitreatment) mediate(othersecurity)

*E8. Sensitivity Analysis
	*Model 1(No Controls)
	medsens(logit moralbi hitreatment) (regress support hitreatment moralbi), /// 
		treat(hitreatment) mediate(moralbi)
	*Model 2(Pretreatment Controls)
	medsens(logit moralbi hitreatment `pretreatment2') /// 
		(regress support hitreatment moralbi `pretreatment2'), /// 
		treat(hitreatment) mediate(moralbi)

macro drop pretreatment2
********************************************************************************
********************************************************************************
*Appendix F. Perceptions of Threat Follow-Up Experiment
*Load Data
use "ExperimentFollowUps.dta", clear
*F1. Results
	*1. Perceptions of threat are roughly equal across FPR and HI scenarios
	prtest threatbi if perceivedthreat==1, by(hi2) 
	*2. Moral obligation significantly higher in HI scenario
	prtest moralbi if perceivedthreat==1, by(hi2)
	
*F2. Perceptions of Threat and Moral Obligation by Treatment
*Figure created in Excel using point estimates and confidence intervals from the following:
	*Perceived Threat
	prtest threatbi if perceivedthreat==1, by(hi2) 
	*Moral Obligation
	prtest moralbi if perceivedthreat==1, by(hi2)
	
*F4. Sample Demographics
	tab1 pid3 educ3 gender if perceivedthreat==1


********************************************************************************
********************************************************************************
*Appendix G. Experiment Three
*Load Data
use "ExperimentThree.dta", clear

*G2. Sample Demographics
	tab1 pid3 educ3 gender income3

*G3. Comparison of Binary and Categorical Measures of Support
*Descriptive Comparison of Binary and Categorical Support by Treatment Scenario
*Binary Support
	*Foreign Policy Restraint
	tab supportbi if treatmentid==0
	*Humanitarian Intervention
	tab supportbi if treatmentid==1
	*Values in the "Effect of Humanitarian Intervention" column are calculated by 
	*substracting the "Humanitarian Intervention" column from the "Foreign Policy Restraint" column. 
*Categorical Support
	*Foreign Policy Restraint
	tab support if treatmentid==0
	*Humanitarian Intervention
	tab support if treatmentid==1
	*Values in the "Effect of Humanitarian Intervention" column are calculated by 
	*substracting the "Humanitarian Intervention" column from the "Foreign Policy Restraint" column. 

*Binary and Categorical Comparison of Means by Treatment Scenario
	*Binary Support
	prtest supportbi, by(treatmentid)
	*Catgorical Support
	ttest support, by(treatmentid)

*G4. Mediation Analysis
*Graph: Results of Mediation Analysis
	*Load spreadsheet with point estimtates and confidence intervals for each potential mediator,
	*based on results from Table 5 of the manuscript (see ReplicationFile1)
	use "ACMEPlot.dta", clear
	eclplot ACME lower upper Mediators, hor xline(0) ylabel(1(1) 8)

*Moral Mediators of Support Controlling for Other Mediators
	*Load Data
	use "ExperimentThree.dta", clear
*Harm to civilians
	*Treatment Effect
	prtest harm, by(treatmentid)
	*ACME and % of Total Effect Mediated
	medeff(logit harm treatmentid) /// 
		(logit supportbi treatmentid harm /// 
		hrights disorder values civilized security othersecurity), /// 
		treat(treatmentid) mediate(harm)
*Perpetrators able to get away with human rights abuse
	*Treatment Effect
	prtest hrights, by(treatmentid)
	*ACME and % of Total Effect Mediated
	medeff(logit hrights treatmentid) /// 
		(logit supportbi treatmentid hrights /// 
		harm disorder values civilized security othersecurity), /// 
		treat(treatmentid) mediate(hrights)
*Disorder within international society
	*Treatment Effect
	prtest disorder, by(treatmentid)
	*ACME and % of Total Effect Mediated
	medeff(logit disorder treatmentid) /// 
		(logit supportbi treatmentid disorder /// 
		harm hrights values civilized security othersecurity), /// 
		treat(treatmentid) mediate(disorder)
*Betray values and identity
	*Treatment Effect
	prtest values, by(treatmentid)
	*ACME and % of Total Effect Mediated
	medeff(logit values treatmentid) /// 
		(logit supportbi treatmentid values /// 
		harm hrights disorder civilized security othersecurity), /// 
		treat(treatmentid) mediate(values)
*Violate Expectations of civilized country
	*Treatment Effect
	prtest civilized, by(treatmentid)
	*ACME and % of Total Effect Mediated
	medeff(logit civilized treatmentid) /// 
		(logit supportbi treatmentid civilized /// 
		harm hrights disorder values security othersecurity), /// 
		treat(treatmentid) mediate(civilized)

*Correlation Matrix for Moral Mediators
corr harm hrights values disorder civilized

*Mediation Analysis Controlling for Pretreatment Covariates
local pretreatment3 donated volunteer donatevol hawk gender news education pid
	*Harm to civilians
	medeff(logit harm treatmentid `pretreatment3') /// 
		(logit supportbi treatmentid harm `pretreatment3'), /// 
		treat(treatmentid) mediate(harm)
	*Perpetrators able to get away with human rights abuse
	medeff(logit hrights treatmentid `pretreatment3') /// 
		(logit supportbi treatmentid hrights `pretreatment3'), /// 
		treat(treatmentid) mediate(hrights)
	*Disorder within international soceity
	medeff(logit disorder treatmentid `pretreatment3') /// 
		(logit supportbi treatmentid disorder `pretreatment3'), /// 
		treat(treatmentid) mediate(disorder)
	*Betray values and identity
	medeff(logit values treatmentid `pretreatment3') /// 
		(logit supportbi treatmentid values `pretreatment3'), /// 
		treat(treatmentid) mediate(values)
	*Violate expectations of civilized country
	medeff(logit civilized treatmentid `pretreatment3') /// 
		(logit supportbi treatmentid civilized `pretreatment3'), /// 
		treat(treatmentid) mediate(civilized)

*G5. Sensitivity Analysis
	*Model 1 (No Controls)
	medsens(logit harm treatmentid) (regress support treatmentid harm), /// 
		treat(treatmentid) mediate(harm)
	*Model 2 (Pretreatment Controls)
	medsens(logit harm treatmentid `pretreatment3') /// 
		(regress support treatmentid harm `pretreatment3'), /// 
		treat(treatmentid) mediate(harm)

macro drop pretreatment3
********************************************************************************
********************************************************************************	
*Appendix H. Moral Foundations and Party Identification
*Harm
	*Democrats
	prtest harm if democrat==1, by(treatmentid)
	*Republicans
	prtest harm if republican==1, by(treatmentid)
	*Independent
	prtest harm if independent==1, by(treatmentid)
*Human Rights
	*Democrats
	prtest hrights if democrat==1, by(treatmentid)
	*Republicans
	prtest hrights if republican==1, by(treatmentid)
	*Independent
	prtest hrights if independent==1, by(treatmentid)
*Values/Identity
	*Democrats
	prtest values if democrat==1, by(treatmentid)
	*Republicans
	prtest values if republican==1, by(treatmentid)
	*Independent
	prtest values if independent==1, by(treatmentid)
*Disorder
	*Democrats
	prtest disorder if democrat==1, by(treatmentid)
	*Republicans
	prtest disorder if republican==1, by(treatmentid)
	*Independent
	prtest disorder if independent==1, by(treatmentid)
*Civilized
	*Democrats
	prtest civilized if democrat==1, by(treatmentid)
	*Republicans
	prtest civilized if republican==1, by(treatmentid)
	*Independent
	prtest civilized if independent==1, by(treatmentid)
*Security
	*Democrats
	prtest security if democrat==1, by(treatmentid)
	*Republicans
	prtest security if republican==1, by(treatmentid)
	*Independent
	prtest security if independent==1, by(treatmentid)
*Others' Security
	*Democrats
	prtest othersecurity if democrat==1, by(treatmentid)
	*Republicans
	prtest othersecurity if republican==1, by(treatmentid)
	*Independent
	prtest othersecurity if independent==1, by(treatmentid)
	
